==> openshift-model-5.9.0-sources.jar: io/fabric8/openshift/api/model/OpenIDClaimsFluentImpl.java <==
package io.fabric8.openshift.api.model;

import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.ArrayList;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.String;
import java.lang.Boolean;
import java.util.function.Predicate;

 /**
  * Generated
  */
public class OpenIDClaimsFluentImpl<A extends io.fabric8.openshift.api.model.OpenIDClaimsFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.OpenIDClaimsFluent<A>{
  public OpenIDClaimsFluentImpl() {
  }
  public OpenIDClaimsFluentImpl(io.fabric8.openshift.api.model.OpenIDClaims instance) {
    this.withEmail(instance.getEmail()); 
    this.withName(instance.getName()); 
    this.withPreferredUsername(instance.getPreferredUsername()); 
  }
  private java.util.List<java.lang.String> email = new java.util.ArrayList<java.lang.String>();
  private java.util.List<java.lang.String> name = new java.util.ArrayList<java.lang.String>();
  private java.util.List<java.lang.String> preferredUsername = new java.util.ArrayList<java.lang.String>();
  public A addToEmail(java.lang.Integer index,java.lang.String item) {
    if (this.email == null) {this.email = new java.util.ArrayList<java.lang.String>();}
    this.email.add(index, item);
    return (A)this;
  }
  public A setToEmail(java.lang.Integer index,java.lang.String item) {
    if (this.email == null) {this.email = new java.util.ArrayList<java.lang.String>();}
    this.email.set(index, item); return (A)this;
  }
  public A addToEmail(java.lang.String... items) {
    if (this.email == null) {this.email = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.email.add(item);} return (A)this;
  }
  public A addAllToEmail(java.util.Collection<java.lang.String> items) {
    if (this.email == null) {this.email = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.email.add(item);} return (A)this;
  }
  public A removeFromEmail(java.lang.String... items) {
    for (java.lang.String item : items) {if (this.email!= null){ this.email.remove(item);}} return (A)this;
  }
  public A removeAllFromEmail(java.util.Collection<java.lang.String> items) {
    for (java.lang.String item : items) {if (this.email!= null){ this.email.remove(item);}} return (A)this;
  }
  public java.util.List<java.lang.String> getEmail() {
    return this.email;
  }
  public java.lang.String getEmail(java.lang.Integer index) {
    return this.email.get(index);
  }
  public java.lang.String getFirstEmail() {
    return this.email.get(0);
  }
  public java.lang.String getLastEmail() {
    return this.email.get(email.size() - 1);
  }
  public java.lang.String getMatchingEmail(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: email) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingEmail(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: email) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withEmail(java.util.List<java.lang.String> email) {
    if (email != null) {this.email = new java.util.ArrayList<java.lang.String>(); for (java.lang.String item : email){this.addToEmail(item);}} else { this.email = null;} return (A) this;
  }
  public A withEmail(java.lang.String... email) {
    if (this.email != null) {this.email.clear();}
    if (email != null) {for (java.lang.String item :email){ this.addToEmail(item);}} return (A) this;
  }
  public java.lang.Boolean hasEmail() {
    return email != null && !email.isEmpty();
  }
  public A addNewEmail(java.lang.String arg0) {
    return (A)addToEmail(new String(arg0));
  }
  public A addToName(java.lang.Integer index,java.lang.String item) {
    if (this.name == null) {this.name = new java.util.ArrayList<java.lang.String>();}
    this.name.add(index, item);
    return (A)this;
  }
  public A setToName(java.lang.Integer index,java.lang.String item) {
    if (this.name == null) {this.name = new java.util.ArrayList<java.lang.String>();}
    this.name.set(index, item); return (A)this;
  }
  public A addToName(java.lang.String... items) {
    if (this.name == null) {this.name = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.name.add(item);} return (A)this;
  }
  public A addAllToName(java.util.Collection<java.lang.String> items) {
    if (this.name == null) {this.name = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.name.add(item);} return (A)this;
  }
  public A removeFromName(java.lang.String... items) {
    for (java.lang.String item : items) {if (this.name!= null){ this.name.remove(item);}} return (A)this;
  }
  public A removeAllFromName(java.util.Collection<java.lang.String> items) {
    for (java.lang.String item : items) {if (this.name!= null){ this.name.remove(item);}} return (A)this;
  }
  public java.util.List<java.lang.String> getName() {
    return this.name;
  }
  public java.lang.String getName(java.lang.Integer index) {
    return this.name.get(index);
  }
  public java.lang.String getFirstName() {
    return this.name.get(0);
  }
  public java.lang.String getLastName() {
    return this.name.get(name.size() - 1);
  }
  public java.lang.String getMatchingName(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: name) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingName(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: name) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withName(java.util.List<java.lang.String> name) {
    if (name != null) {this.name = new java.util.ArrayList<java.lang.String>(); for (java.lang.String item : name){this.addToName(item);}} else { this.name = null;} return (A) this;
  }
  public A withName(java.lang.String... name) {
    if (this.name != null) {this.name.clear();}
    if (name != null) {for (java.lang.String item :name){ this.addToName(item);}} return (A) this;
  }
  public java.lang.Boolean hasName() {
    return name != null && !name.isEmpty();
  }
  public A addNewName(java.lang.String arg0) {
    return (A)addToName(new String(arg0));
  }
  public A addToPreferredUsername(java.lang.Integer index,java.lang.String item) {
    if (this.preferredUsername == null) {this.preferredUsername = new java.util.ArrayList<java.lang.String>();}
    this.preferredUsername.add(index, item);
    return (A)this;
  }
  public A setToPreferredUsername(java.lang.Integer index,java.lang.String item) {
    if (this.preferredUsername == null) {this.preferredUsername = new java.util.ArrayList<java.lang.String>();}
    this.preferredUsername.set(index, item); return (A)this;
  }
  public A addToPreferredUsername(java.lang.String... items) {
    if (this.preferredUsername == null) {this.preferredUsername = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.preferredUsername.add(item);} return (A)this;
  }
  public A addAllToPreferredUsername(java.util.Collection<java.lang.String> items) {
    if (this.preferredUsername == null) {this.preferredUsername = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.preferredUsername.add(item);} return (A)this;
  }
  public A removeFromPreferredUsername(java.lang.String... items) {
    for (java.lang.String item : items) {if (this.preferredUsername!= null){ this.preferredUsername.remove(item);}} return (A)this;
  }
  public A removeAllFromPreferredUsername(java.util.Collection<java.lang.String> items) {
    for (java.lang.String item : items) {if (this.preferredUsername!= null){ this.preferredUsername.remove(item);}} return (A)this;
  }
  public java.util.List<java.lang.String> getPreferredUsername() {
    return this.preferredUsername;
  }
  public java.lang.String getPreferredUsername(java.lang.Integer index) {
    return this.preferredUsername.get(index);
  }
  public java.lang.String getFirstPreferredUsername() {
    return this.preferredUsername.get(0);
  }
  public java.lang.String getLastPreferredUsername() {
    return this.preferredUsername.get(preferredUsername.size() - 1);
  }
  public java.lang.String getMatchingPreferredUsername(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: preferredUsername) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingPreferredUsername(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: preferredUsername) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withPreferredUsername(java.util.List<java.lang.String> preferredUsername) {
    if (preferredUsername != null) {this.preferredUsername = new java.util.ArrayList<java.lang.String>(); for (java.lang.String item : preferredUsername){this.addToPreferredUsername(item);}} else { this.preferredUsername = null;} return (A) this;
  }
  public A withPreferredUsername(java.lang.String... preferredUsername) {
    if (this.preferredUsername != null) {this.preferredUsername.clear();}
    if (preferredUsername != null) {for (java.lang.String item :preferredUsername){ this.addToPreferredUsername(item);}} return (A) this;
  }
  public java.lang.Boolean hasPreferredUsername() {
    return preferredUsername != null && !preferredUsername.isEmpty();
  }
  public A addNewPreferredUsername(java.lang.String arg0) {
    return (A)addToPreferredUsername(new String(arg0));
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    OpenIDClaimsFluentImpl that = (OpenIDClaimsFluentImpl) o;
    if (email != null ? !email.equals(that.email) :that.email != null) return false;
    if (name != null ? !name.equals(that.name) :that.name != null) return false;
    if (preferredUsername != null ? !preferredUsername.equals(that.preferredUsername) :that.preferredUsername != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(email,  name,  preferredUsername,  super.hashCode());
  }
  
}

==> openshift-model-5.10.2-sources.jar: io/fabric8/openshift/api/model/OpenIDClaimsFluentImpl.java <==
package io.fabric8.openshift.api.model;

import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class OpenIDClaimsFluentImpl<A extends io.fabric8.openshift.api.model.OpenIDClaimsFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.OpenIDClaimsFluent<A>{
  public OpenIDClaimsFluentImpl() {
  }
  public OpenIDClaimsFluentImpl(io.fabric8.openshift.api.model.OpenIDClaims instance) {
    this.withEmail(instance.getEmail()); 
    this.withName(instance.getName()); 
    this.withPreferredUsername(instance.getPreferredUsername()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.util.List<java.lang.String> email = new java.util.ArrayList<java.lang.String>();
  private java.util.List<java.lang.String> name = new java.util.ArrayList<java.lang.String>();
  private java.util.List<java.lang.String> preferredUsername = new java.util.ArrayList<java.lang.String>();
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public A addToEmail(java.lang.Integer index,java.lang.String item) {
    if (this.email == null) {this.email = new java.util.ArrayList<java.lang.String>();}
    this.email.add(index, item);
    return (A)this;
  }
  public A setToEmail(java.lang.Integer index,java.lang.String item) {
    if (this.email == null) {this.email = new java.util.ArrayList<java.lang.String>();}
    this.email.set(index, item); return (A)this;
  }
  public A addToEmail(java.lang.String... items) {
    if (this.email == null) {this.email = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.email.add(item);} return (A)this;
  }
  public A addAllToEmail(java.util.Collection<java.lang.String> items) {
    if (this.email == null) {this.email = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.email.add(item);} return (A)this;
  }
  public A removeFromEmail(java.lang.String... items) {
    for (java.lang.String item : items) {if (this.email!= null){ this.email.remove(item);}} return (A)this;
  }
  public A removeAllFromEmail(java.util.Collection<java.lang.String> items) {
    for (java.lang.String item : items) {if (this.email!= null){ this.email.remove(item);}} return (A)this;
  }
  public java.util.List<java.lang.String> getEmail() {
    return this.email;
  }
  public java.lang.String getEmail(java.lang.Integer index) {
    return this.email.get(index);
  }
  public java.lang.String getFirstEmail() {
    return this.email.get(0);
  }
  public java.lang.String getLastEmail() {
    return this.email.get(email.size() - 1);
  }
  public java.lang.String getMatchingEmail(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: email) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingEmail(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: email) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withEmail(java.util.List<java.lang.String> email) {
    if (email != null) {this.email = new java.util.ArrayList<java.lang.String>(); for (java.lang.String item : email){this.addToEmail(item);}} else { this.email = null;} return (A) this;
  }
  public A withEmail(java.lang.String... email) {
    if (this.email != null) {this.email.clear();}
    if (email != null) {for (java.lang.String item :email){ this.addToEmail(item);}} return (A) this;
  }
  public java.lang.Boolean hasEmail() {
    return email != null && !email.isEmpty();
  }
  public A addNewEmail(java.lang.String arg0) {
    return (A)addToEmail(new String(arg0));
  }
  public A addToName(java.lang.Integer index,java.lang.String item) {
    if (this.name == null) {this.name = new java.util.ArrayList<java.lang.String>();}
    this.name.add(index, item);
    return (A)this;
  }
  public A setToName(java.lang.Integer index,java.lang.String item) {
    if (this.name == null) {this.name = new java.util.ArrayList<java.lang.String>();}
    this.name.set(index, item); return (A)this;
  }
  public A addToName(java.lang.String... items) {
    if (this.name == null) {this.name = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.name.add(item);} return (A)this;
  }
  public A addAllToName(java.util.Collection<java.lang.String> items) {
    if (this.name == null) {this.name = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.name.add(item);} return (A)this;
  }
  public A removeFromName(java.lang.String... items) {
    for (java.lang.String item : items) {if (this.name!= null){ this.name.remove(item);}} return (A)this;
  }
  public A removeAllFromName(java.util.Collection<java.lang.String> items) {
    for (java.lang.String item : items) {if (this.name!= null){ this.name.remove(item);}} return (A)this;
  }
  public java.util.List<java.lang.String> getName() {
    return this.name;
  }
  public java.lang.String getName(java.lang.Integer index) {
    return this.name.get(index);
  }
  public java.lang.String getFirstName() {
    return this.name.get(0);
  }
  public java.lang.String getLastName() {
    return this.name.get(name.size() - 1);
  }
  public java.lang.String getMatchingName(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: name) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingName(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: name) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withName(java.util.List<java.lang.String> name) {
    if (name != null) {this.name = new java.util.ArrayList<java.lang.String>(); for (java.lang.String item : name){this.addToName(item);}} else { this.name = null;} return (A) this;
  }
  public A withName(java.lang.String... name) {
    if (this.name != null) {this.name.clear();}
    if (name != null) {for (java.lang.String item :name){ this.addToName(item);}} return (A) this;
  }
  public java.lang.Boolean hasName() {
    return name != null && !name.isEmpty();
  }
  public A addNewName(java.lang.String arg0) {
    return (A)addToName(new String(arg0));
  }
  public A addToPreferredUsername(java.lang.Integer index,java.lang.String item) {
    if (this.preferredUsername == null) {this.preferredUsername = new java.util.ArrayList<java.lang.String>();}
    this.preferredUsername.add(index, item);
    return (A)this;
  }
  public A setToPreferredUsername(java.lang.Integer index,java.lang.String item) {
    if (this.preferredUsername == null) {this.preferredUsername = new java.util.ArrayList<java.lang.String>();}
    this.preferredUsername.set(index, item); return (A)this;
  }
  public A addToPreferredUsername(java.lang.String... items) {
    if (this.preferredUsername == null) {this.preferredUsername = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.preferredUsername.add(item);} return (A)this;
  }
  public A addAllToPreferredUsername(java.util.Collection<java.lang.String> items) {
    if (this.preferredUsername == null) {this.preferredUsername = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.preferredUsername.add(item);} return (A)this;
  }
  public A removeFromPreferredUsername(java.lang.String... items) {
    for (java.lang.String item : items) {if (this.preferredUsername!= null){ this.preferredUsername.remove(item);}} return (A)this;
  }
  public A removeAllFromPreferredUsername(java.util.Collection<java.lang.String> items) {
    for (java.lang.String item : items) {if (this.preferredUsername!= null){ this.preferredUsername.remove(item);}} return (A)this;
  }
  public java.util.List<java.lang.String> getPreferredUsername() {
    return this.preferredUsername;
  }
  public java.lang.String getPreferredUsername(java.lang.Integer index) {
    return this.preferredUsername.get(index);
  }
  public java.lang.String getFirstPreferredUsername() {
    return this.preferredUsername.get(0);
  }
  public java.lang.String getLastPreferredUsername() {
    return this.preferredUsername.get(preferredUsername.size() - 1);
  }
  public java.lang.String getMatchingPreferredUsername(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: preferredUsername) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingPreferredUsername(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: preferredUsername) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withPreferredUsername(java.util.List<java.lang.String> preferredUsername) {
    if (preferredUsername != null) {this.preferredUsername = new java.util.ArrayList<java.lang.String>(); for (java.lang.String item : preferredUsername){this.addToPreferredUsername(item);}} else { this.preferredUsername = null;} return (A) this;
  }
  public A withPreferredUsername(java.lang.String... preferredUsername) {
    if (this.preferredUsername != null) {this.preferredUsername.clear();}
    if (preferredUsername != null) {for (java.lang.String item :preferredUsername){ this.addToPreferredUsername(item);}} return (A) this;
  }
  public java.lang.Boolean hasPreferredUsername() {
    return preferredUsername != null && !preferredUsername.isEmpty();
  }
  public A addNewPreferredUsername(java.lang.String arg0) {
    return (A)addToPreferredUsername(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    OpenIDClaimsFluentImpl that = (OpenIDClaimsFluentImpl) o;
    if (email != null ? !email.equals(that.email) :that.email != null) return false;
    if (name != null ? !name.equals(that.name) :that.name != null) return false;
    if (preferredUsername != null ? !preferredUsername.equals(that.preferredUsername) :that.preferredUsername != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(email,  name,  preferredUsername,  additionalProperties,  super.hashCode());
  }
  
}
